<template>
    <div>
        <el-dialog :title="invalidDealState.title" :close-on-click-modal="false"  v-model="invalidDealState.invalidDealDialogVisible" width="30%">
            <el-form
                :model="invalidDealState.invalidDealForm"
                ref="invalidDealFormRef"
                size="default"
                label-width="150px">
                <el-row>
                    <el-col :span="24" class="mb20">
                        <el-form-item label="失效原因:" prop="reason">
                            <el-select class="input-add" v-model="invalidDealState.invalidDealForm.reason" placeholder="失效原因">
                                <el-option
                                    v-for="item in invalidDealState.reasonList"
                                    :key="item.id"
                                    :value="item.id"
                                    :label="item.name"
                                ></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="24" class="mb20">
                        <el-form-item label="备注:" prop="remark">
                            <el-input type="textarea" :rows="3" v-model="invalidDealState.invalidDealForm.remark" placeholder="备注" class="input-add">
                            </el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="invalidDealState.invalidDealDialogVisible = !invalidDealState.invalidDealDialogVisible" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitInvalidDeal" v-throttle size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script setup lang="ts">
import { reactive, ref } from 'vue'
import {InvalidDealStateType, materialType} from '..'

const invalidDealFormRef = ref()

const invalidDealState = reactive<InvalidDealStateType>({
    title: '',
    invalidDealDialogVisible: false,
    invalidDealForm: {
        id: null,
        reason: null,
        remark: null,
    },
    reasonList:[
        {id: 0, name:'完好'},
        {id: 1, name:'损坏'},
        {id: 2, name:'丢失'},
        {id: 3, name:'过期'},
        {id: 4, name:'其他'}
    ]
})

const openInvalidDealDialog = (value: materialType) => {
    invalidDealState.invalidDealDialogVisible = true
    invalidDealState.invalidDealForm.id = value.id
    invalidDealState.invalidDealForm.reason = value.materialStatus
    invalidDealState.invalidDealForm.remark = value.remark
}

const submitInvalidDeal = () => {
    emit('refreshInvalidDeal',invalidDealState.invalidDealForm)
    invalidDealState.invalidDealDialogVisible = false
}

const emit = defineEmits(['refreshInvalidDeal'])

defineExpose({
    openInvalidDealDialog
})

</script>

<style scoped>

</style>
